#!/usr/bin/env node
const pkg = require("./package.json");
const { execSync } = require("child_process");
const fs = require("fs");
const os = require("os");
const path = require("path");

/**
 * return Git commit hash or 'modified' if git diff returns something
 */
function getGitCommitHash() {
  const diff = execSync("git diff-index --name-only HEAD")
    .toString()
    .trim();

  if (diff) {
    console.log("MODIFIED FILES:");
    console.log(diff);
    console.log("");
    return "modified";
  }

  return execSync("git rev-parse --short HEAD")
    .toString()
    .trim();
}

/**
 * Generate VUE_APP_ environment variables
 */
function writeEnv(file = ".env.local") {
  try {
    const now = new Date();
    const buildDate = now.toUTCString();
    const variant = process.argv[2] || "";
    const hash = getGitCommitHash();
    const pid = pkg.name;
    const title = pkg.title;
    const version = pkg.version;
    let generator = pid;
    if (variant) generator += `-${variant}`;
    generator += `-v${version} Vue ${buildDate} (${hash})`;

    const author = `plumelearning.com `;

    let content = `VUE_APP_TITLE="${title}"${os.EOL}`;
    content += `VUE_APP_BUILD_DATE="${buildDate}"${os.EOL}`;
    content += `VUE_APP_COMMIT_HASH="${hash}"${os.EOL}`;
    content += `VUE_APP_AUTHOR="${author}"${os.EOL}`;
    content += `VUE_APP_GENERATOR="${generator}"${os.EOL}`;
    if (variant) content += `VUE_APP_VARIANT="${variant}"${os.EOL}`;

    // write file
    const fd = fs.openSync(".env.local", "w");
    fs.writeSync(fd, content, null, null);
    fs.closeSync(fd);
  } catch (msg) {
    throw new Error(`writeEnv(${file}): ${msg}`);
  }
}

/**
 * main
 */
writeEnv(".env.local");
