module.exports = {
  theme: {
    screens: {
      sm: "30rem" /* 480 */,
      md: "48rem" /* 768 */,
      lg: "64rem" /* 1024 */,
      xl: "80rem" /* 1280 */
    },
    fontFamily: {
      body: [
        "Roboto",
        '"Fira Sans"',
        "-apple-system",
        "BlinkMacSystemFont",
        '"Segoe UI"',
        '"Helvetica Neue"',
        "Arial",
        '"Noto Sans"',
        "sans-serif",
        '"Apple Color Emoji"',
        '"Segoe UI Emoji"',
        '"Segoe UI Symbol"',
        '"Noto Color Emoji"'
      ],
      headings: [
        "Google Sans",
        "Roboto",
        '"Fira Sans Condensed"',
        "-apple-system",
        "BlinkMacSystemFont",
        '"Segoe UI"',
        '"Helvetica Neue"',
        "Arial",
        '"Noto Sans"',
        "sans-serif",
        '"Apple Color Emoji"',
        '"Segoe UI Emoji"',
        '"Segoe UI Symbol"',
        '"Noto Color Emoji"'
      ],
      icons: ['"Font Awesome 5 Free"', "sans-serif"]
    },
    fontSize: {
      xs: "0.75rem",
      sm: "0.875rem",
      base: "1rem",
      lg: "1.125rem",
      xl: "1.25rem",
      "2xl": "1.5rem",
      "3xl": "1.875rem",
      "4xl": "2.25rem",
      "5xl": "3rem",
      "6xl": "3.875rem"
    },
    fontWeight: {
      light: "300",
      normal: "400",
      medium: "500",
      semibold: "600",
      bold: "700"
    },
    boxShadow: {
      default: "var(--shadow-default)",
      md: "var(--shadow-md)",
      lg: "var(--shadow-lg)",
      xl: "var(--shadow-xl)",
      outline: "var(--shadow-outline)",
      focus: "var(--shadow-focus)",
      tabs: "var(--shadow-tabs)",
      z1: "var(--shadow-z1)",
      z2: "var(--shadow-z2)",
      z3: "var(--shadow-z3)",
      z4: "var(--shadow-z4)",
      z5: "var(--shadow-z5)",
      z6: "var(--shadow-z6)",
      z7: "var(--shadow-z7)",
      z8: "var(--shadow-z8)"
    },
    extend: {
      minWidth: {
        xs: "20rem",
        sm: "24rem",
        "0": "0",
        "1/4": "25%",
        "1/2": "50%",
        "3/4": "75%",
        full: "100%"
      },
      minHeight: {
        xs: "20rem",
        sm: "24rem",
        "0": "0",
        "1/4": "25%",
        "1/2": "50%",
        "3/4": "75%",
        full: "100%"
      },
      colors: {
        // base color palette
        white: "#ffffff",
        black: "#1a202c",
        outline: "var(--color-outline)",
        blue: {
          100: "#ebf8ff",
          200: "#bee3f8",
          300: "#90cdf4",
          400: "#63b3ed",
          500: "#4299e1",
          600: "#3182ce",
          700: "#2b6cb0",
          800: "#2c5282",
          900: "#2a4365"
        },
        bluegray: {
          100: "#cfd8dc",
          200: "#b0bec5",
          300: "#90a4ae",
          400: "#78909c",
          500: "#607d8b",
          600: "#546e7a",
          700: "#455a64",
          800: "#37474f",
          900: "#263238"
        },
        gray: {
          100: "#f7fafc",
          200: "#edf2f7",
          300: "#e2e8f0",
          400: "#cbd5e0",
          500: "#a0aec0",
          600: "#718096",
          700: "#4a5568",
          800: "#2d3748",
          900: "#1a202c"
        },
        red: {
          100: "#fff5f5",
          200: "#fed7d7",
          300: "#feb2b2",
          400: "#fc8181",
          500: "#f56565",
          600: "#e53e3e",
          700: "#c53030",
          800: "#9b2c2c",
          900: "#742a2a"
        },
        orange: {
          100: "#fffaf0",
          200: "#feebc8",
          300: "#fbd38d",
          400: "#f6ad55",
          500: "#ed8936",
          600: "#dd6b20",
          700: "#c05621",
          800: "#9c4221",
          900: "#7b341e"
        },
        yellow: {
          100: "#fffff0",
          200: "#fefcbf",
          300: "#faf089",
          400: "#f6e05e",
          500: "#ecc94b",
          600: "#d69e2e",
          700: "#b7791f",
          800: "#975a16",
          900: "#744210"
        },
        green: {
          100: "#f0fff4",
          200: "#c6f6d5",
          300: "#9ae6b4",
          400: "#68d391",
          500: "#48bb78",
          600: "#38a169",
          700: "#2f855a",
          800: "#276749",
          900: "#22543d"
        },
        google: {
          blue: "#1a73e8",
          green: "#369B69",
          amber: "#fbbc04",
          red: "#ea4335"
        },

        googleLight: {
          blue: "#e8f0fe",
          green: "#dcf4eb",
          amber: "#feefc3",
          red: "#ffc7a8"
        },

        // application colors
        primary: "var(--color-primary)",
        secondary: "var(--color-secondary)",
        tertiary: "var(--color-tertiary)",
        info: "var(--color-info)",
        instruction: "var(--color-instruction)",
        note: "var(--color-note)",
        correct: "var(--color-correct)",
        incorrect: "var(--color-incorrect)",
        success: "var(--color-correct)",
        error: "var(--color-incorrect)",
        disabled: "var(--color-disabled)",
        neutral: "var(--color-neutral)",
        background: theme => theme("colors.surface.base"),

        surface: {
          base: "var(--color-surface-base)",
          info: "var(--color-surface-info)",
          instruction: "var(--color-surface-instruction)",
          note: "var(--color-surface-note)",
          correct: "var(--color-surface-correct)",
          incorrect: "var(--color-surface-incorrect)",
          success: "var(--color-surface-correct)",
          error: "var(--color-surface-incorrect)",
          disabled: "var(--color-surface-disabled)",
          primary: "var(--color-surface-primary)",
          secondary: "var(--color-surface-secondary)",
          tertiary: "var(--color-surface-tertiary)",
          neutral: "var(--color-surface-neutral)"
        },

        on: {
          light: "var(--color-on-light)",
          dark: "var(--color-on-dark)",
          base: "var(--color-on-light)",
          info: "var(--color-on-light)",
          instruction: "var(--color-instruction)",
          note: "var(--color-note)",
          correct: "var(--color-on-light)",
          incorrect: "var(--color-on-light)",
          success: "var(--color-on-light)",
          error: "var(--color-on-light)",
          disabled: "var(--color-on-light)",
          primary: "var(--color-on-dark)",
          secondary: "var(--color-on-dark)",
          tertiary: "var(--color-on-light)",
          neutral: "var(--color-on-dark)"
        },

        outline: "var(--color-outline)"
      }
    }
  },
  plugins: [
    function({ addUtilities }) {
      const gridUtilities = {
        ".grid-15": {
          "grid-template-columns": "repeat(auto-fit, minmax(15rem, 1fr))"
        },
        ".grid-16": {
          "grid-template-columns": "repeat(auto-fit, minmax(16rem, 1fr))"
        },
        ".grid-20": {
          "grid-template-columns": "repeat(auto-fit, minmax(20rem, 1fr))"
        },
        ".grid-24": {
          "grid-template-columns": "repeat(auto-fit, minmax(24rem, 1fr))"
        }
      };

      addUtilities(gridUtilities);
    }
  ]
};
