/**
@license
Copyright 2020 Google LLC


Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

const selectors =
  "a[href]" +
  ",area[href]" +
  ",button:not([disabled])" +
  ",input:not([disabled])" +
  ",select:not([disabled])" +
  ",textarea:not([disabled])";

const focusSelectors = selectors + ",[tabindex]";

const tabSelectors = selectors + ",[tabindex='0']";

const isFocusable = function(root) {
  if (!(root instanceof Element)) {
    return false;
  }
  for (let selector of focusSelectors.split(",")) {
    if (root.matches(selector)) return true;
  }
  return false;
};

const findFocusable = function(root) {
  if (!(root instanceof Element)) return null;
  return root.querySelectorAll(focusSelectors);
};

const findFirstFocusable = function(root) {
  if (!(root instanceof Element)) return null;
  return root.querySelectorAll(focusSelectors)[0];
};

const findTabbable = function(root) {
  if (!(root instanceof Element)) return null;
  return root.querySelectorAll(tabSelectors);
};

const logFocus = function(root) {
  if (!(root instanceof Element)) return;
  root.querySelectorAll(focusSelectors).forEach(el => {
    el.addEventListener("focus", e => window.console.log(e.target));
  });
};

export { isFocusable, findFocusable, findFirstFocusable, findTabbable, logFocus };
