/**
@license
Copyright 2020 Google LLC


Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

import images from "@/image-manifest.json";
const DEBUG = false;

if (DEBUG) window.console.log("images to preload: ", images);

function loadImages(componentName) {
  if (DEBUG) window.console.log(`${componentName} images: `, images[componentName]);

  return new Promise((resolve, reject) => {
    try {
      if (!images[componentName]) {
        if (DEBUG) window.console.log("no images to load for component: " + componentName);
        resolve();
      } else {
        const imagesArray = images[componentName];
        let loadedImageCount = 0;
        for (const imageName of imagesArray) {
          const img = new Image();
          img.src = require(`@/assets/images/${imageName}`);
          img.onload = img.onerror = () => {
            loadedImageCount++;
            if (loadedImageCount === imagesArray.length) {
              resolve();
            }
          };
        }
      }
    } catch (msg) {
      window.console.error(msg);
      resolve();
    }
  });
}

export default loadImages;
