/**
@license
Copyright 2020 Google LLC


Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

import smoothscroll from "smoothscroll-polyfill";

smoothscroll.polyfill();

const DEBUG = false;

// if (DEBUG) {
//   window.onscroll = function () {
//     window.console.log(`scrollY ${window.scrollY}`);
//   };
// }

function outOfView(element, margin = { top: 10, bottom: 100 }) {
  // top, bottom values are pixels from window top (not viewport!).
  // only viewport top, bottom vary with scroll
  let el = {},
    vp = {};
  try {
    // viewport (with margins, allowing for fixed elements)
    vp.h = window.innerHeight;
    vp.top = window.scrollY + margin.top;
    vp.bottom = window.scrollY + vp.h - margin.bottom;
    // element
    el.h = element.scrollHeight;
    el.top = getOffsetTop(element);
    el.bottom = el.top + el.h;

    // check for undefined
    Object.keys(vp).forEach(key => {
      if (vp[key] === undefined) throw new Error(`vp.${key} undefined`);
    });
    Object.keys(el).forEach(key => {
      if (el[key] === undefined) throw new Error(`el.${key} undefined`);
    });
  } catch (error) {
    throw new Error(`outOfView: ${error}`);
  }

  let delta = 0;
  // element top is below the viewport top
  if (el.top > vp.top) {
    // element top is in the
    delta = Math.max(el.bottom - vp.bottom, 0); // positive or 0 value
    // don't let el.top scroll above top of viewport
    delta = Math.min(delta, el.top - vp.top);
  }
  // element bottom is above the viewport bottom
  else if (el.bottom < vp.bottom) {
    delta = Math.min(el.top - vp.top, 0); // negative or 0 value
    // don't let el.bottom scroll below bottom of viewport
    delta = Math.max(delta, el.bottom - vp.bottom);
  }
  if (DEBUG) console.log(vp, el, delta);
  return delta;
}

function scrollDistance(node, position, offset) {
  const vh = window.innerHeight;
  const bcr = node.getBoundingClientRect();
  let scroll = offset;
  switch (position) {
    case "top":
    case "start":
      scroll += bcr.top;
      break;
    case "bottom":
      scroll += bcr.bottom - vh;
      break;
    case "nearest":
      if (bcr.top < 0) scroll += bcr.top;
      else if (bcr.bottom > vh) scroll += bcr.bottom - vh;
      break;
    default:
      scroll += (bcr.top + bcr.bottom - vh) / 2;
  }
  if (DEBUG)
    window.console.log(
      `scroll vh ${vh}
       top ${bcr.top} bottom ${bcr.bottom}
       offset ${offset} scroll ${scroll}`
    );
  return scroll;
}

function getOffsetTop(element) {
  let offset = 0;
  do {
    if (!isNaN(element.offsetTop)) {
      offset += element.offsetTop;
    }
    element = element.offsetParent;
  } while (element);
  return offset;
}

function isFixed(element) {
  try {
    if (getComputedStyle(element).position === "fixed") return true;
    else if (element.parentElement) return isFixed(element.parentElement);
    else return false;
  } catch (error) {
    throw new Error(`isFixed(${element.tagName}): ${error}`);
  }
}

export { getOffsetTop, isFixed, outOfView, scrollDistance };
