/**
@license
Copyright 2020 Google LLC


Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

const DEBUG = false;
const TABABLE = "input:not([disabled]),button:not([disabled]),a[href],[tabindex='0']";
const FOCUSABLE = TABABLE + ",[tabindex='-1']";

const focusMixin = {
  methods: {
    /**
     * focus element after Vue has refreshed and Window JS queue is empty
     *
     * @param {HTMLElement} element to recieve focus
     * @param {Number} delay in milliseconds (default: 100)
     * @returns {Boolean}
     */
    focus(element, time = 100) {
      if (element instanceof HTMLElement && element.matches(FOCUSABLE)) {
        this.$nextTick().then(() =>
          this.$nextTick(() =>
            setTimeout(() => {
              if (DEBUG) console.log(`focusing on `, element);
              element.focus();
            }, time)
          )
        );
        return true;
      } else {
        return this.focusFirstDescendant(element);
      }
    },
    focusFirstDescendant(element) {
      if (element instanceof HTMLElement) {
        for (let child of element.childNodes) {
          if (this.focus(child) || this.focusFirstDescendant(child)) {
            return true;
          }
        }
      }
      if (DEBUG) console.error(`focus failed`);
      return false;
    },
    focusableWithin(element) {
      let kids = [];
      if (element instanceof HTMLElement) kids = Array.from(element.querySelectorAll(FOCUSABLE));
      return kids;
    },
    tabableWithin(element) {
      let kids = [];
      if (element instanceof HTMLElement) kids = Array.from(element.querySelectorAll(TABABLE));
      return kids;
    }
  }
};

export default focusMixin;
