/**
@license
Copyright 2020 Google LLC


Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

const DEBUG = false;

export default {
  props: {
    id: {
      type: String,
      required: true
    }
  },
  data() {
    return {
      disabled: true,
      submitted: false,
      saveme: true,
      history: [],
      entries: []
    };
  },
  mounted() {
    if (this.saveme) this.restoreForm();
  },
  methods: {
    onInput() {
      this.disabled = false;
      this.scrollToView(`#${this.id}`);
    },
    onSubmit(event) {
      this.submitted = true;
      this.updateEntries(event);
      this.entries.forEach(entry => this.history.includes(entry) || this.history.push(entry));
      if (this.saveme) this.saveForm();
      this.$emit("submitted");
    },
    saveForm() {
      const data = {
        disabled: this.disabled,
        submitted: this.submitted,
        history: this.history,
        entries: this.entries
      };
      this.$store.commit("SET_FORM", { name: this.id, data: data });
    },
    restoreForm() {
      const data = this.$store.getters.getForm(this.id);
      if (data) {
        this.disabled = !!data.disabled;
        this.submitted = !!data.submitted;
        if (Array.isArray(data.entries)) this.entries = Array.from(data.entries);
      }
    },
    updateEntries() {
      throw "Missing method updateEntries() in component.";
    }
  }
};
