/**
@license
Copyright 2020 Google LLC


Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

export default {
  computed: {
    mcqValues() {
      return this.$store.getters["mcq/values"](this.id);
    },
    mcqCheckedValues() {
      return this.$store.getters["mcq/checkedValues"](this.id);
    },
    mcqExaminedValues() {
      return this.$store.getters["mcq/examinedValues"](this.id);
    },
    mcqIsSubmitted() {
      return this.$store.getters["mcq/isSubmitted"](this.id);
    },
    mcqIsSubmittable() {
      return this.$store.getters["mcq/isSubmittable"](this.id);
    },
    mcqCorrectness() {
      return this.$store.getters["mcq/correctness"](this.id);
    },
    mcqIsCorrect() {
      return this.$store.getters["mcq/isCorrect"](this.id);
    },
    mcqIsIncorrect() {
      return this.$store.getters["mcq/isIncorrect"](this.id);
    },
    mcqUseIcons() {
      return this.$store.getters["mcq/useIcons"](this.id);
    }
  },
  methods: {
    mcqSubmit(buttonElement) {
      this.$store.dispatch("mcq/submit", { id: this.id, button: buttonElement });
    },
    mcqTryAgain() {
      this.$store.dispatch("mcq/tryAgain", { id: this.id });
    },
    mcqSetup(choices, submittable = false, icons = false) {
      this.$store.dispatch("mcq/setup", {
        id: this.id,
        choices,
        submittable,
        icons
      });
    },
    mcqReset(choices) {
      this.$store.dispatch("mcq/reset", { id: this.id, choices });
    },
    mcqSetCorrectness(isCorrect) {
      this.$store.dispatch("mcq/setCorrectness", { id: this.id, correct: isCorrect });
    },
    mcqHasValue(inputValue) {
      return this.$store.getters["mcq/isValue"](this.id, inputValue);
    },

    // input state
    mcqChangeValue(inputValue, checked, clear = false) {
      this.$store.dispatch("mcq/change", {
        id: this.id,
        value: inputValue,
        checked,
        clear
      });
    },
    mcqValueChecked(inputValue) {
      return this.$store.getters["mcq/isCheckedValue"](this.id, inputValue);
    },
    mcqValueExamined(inputValue) {
      return this.$store.getters["mcq/isExaminedValue"](this.id, inputValue);
    },

    // input correctness
    mcqSetValueCorrectness(inputValue, correctness) {
      this.$store.dispatch("mcq/setInputAttribute", {
        id: this.id,
        value: inputValue,
        attribute: { name: "correctness", value: correctness }
      });
    },
    mcqGetValueCorrectness(inputValue) {
      return this.$store.getters["mcq/inputAttribute"](this.id, inputValue, "correctness");
    },
    // correctness indicator
    mcqIconForValue(inputValue) {
      return this.$store.getters["mcq/iconForValue"](this.id, inputValue);
    },
    mcqDisable() {
      this.$store.dispatch("mcq/disable", { id: this.id });
    }
  }
};
