/**
@license
Copyright 2020 Google LLC


Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

import Vue from "vue";

const DEBUG = false;

export default {
  data() {
    return {
      todo: true,
      done: {}
    };
  },
  computed: {
    tasks() {
      return [];
    }
  },
  methods: {
    sayDone(q) {
      if (q) {
        Vue.set(this.done, q, true);
      }
      this.todo = Object.values(this.done).includes(false);
    },
    setPageData() {
      this.$store.dispatch("setPageData", { pageData: this.$data });
    },
    initializeTasks() {
      // initialize the tasks if not set in store
      if (Object.keys(this.done).length === 0 && this.tasks && this.tasks.length > 0) {
        this.done = this.tasks.reduce(function(acc, cur, i) {
          acc[cur] = false;
          return acc;
        }, {});
      }
    }
  },
  computed: {
    dataJSON() {
      return JSON.stringify(this.$data);
    }
  },
  mounted() {
    const pageNo = this.$store.getters.pageNo;
    if (DEBUG) window.console.log(`Stored data page ${pageNo}`);
    const data = this.$store.getters.getPageData(pageNo);
    if (DEBUG) window.console.dir(data);
    Object.assign(this.$data, data);
    if (DEBUG) window.console.dir(this.$data);

    // initialize todo tasks after initializing data variables from store
    // at this point if component has computed tasks array it will be ready
    // for initializtion.
    this.initializeTasks();
  },
  watch: {
    dataJSON: function(value) {
      this.setPageData();
    }
  }
};
