/**
@license
Copyright 2020 Google LLC


Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

import Vue from "vue";
import Router from "vue-router";
import TableOfContents from "./views/toc";
import Alerts from "./views/alerts";

import pm from "./pages";
import loadImages from "@/lib/images";

Vue.use(Router);

const routes = [
  {
    path: "/toc",
    name: "toc",
    component: TableOfContents
  },
  {
    path: "/alerts",
    name: "alerts",
    component: Alerts
  },
  {
    path: "/",
    redirect: { name: "title-page" }
  }
];

pm.pageNames().forEach(name => {
  let path = `/page/${name}`;
  const c = pm.getComponent(name);
  routes.push({
    path,
    name,
    component: c,
    beforeEnter(to, from, next) {
      loadImages(name).finally(() => {
        next();
      });
    }
  });
});

routes.push({
  path: "*",
  redirect: { name: "title-page" }
});

export default new Router({
  routes,
  scrollBehavior() {
    return { x: 0, y: 0 };
  }
});
