/**
@license
Copyright 2020 Google LLC


Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

import Vue from "vue";
import ScormStore from "@plumelearning/scorm-store";
const scormStore = new ScormStore(process.env.VUE_APP_SCORM, "disability_fundamentals");
Object.freeze(scormStore);
// const observedStore = Vue.observable(scormStore);

export default {
  namespaced: true,
  getters: {
    active() {
      return scormStore.active();
    },
    local() {
      return scormStore.local;
    },
    lms() {
      return scormStore.lms;
    }
  },
  actions: {
    recoverState({ commit }) {
      if (scormStore && scormStore.active()) {
        const storedState = scormStore.recover();
        commit("REPLACE_STATE", storedState, { root: true });
      }
    },
    saveState({ rootState }) {
      if (scormStore && scormStore.active()) {
        scormStore.save(rootState);
      }
    },
    saveBookmark({ rootGetters }) {
      const location = rootGetters.bookmark;
      if (scormStore) scormStore.saveBookmark(location);
    },
    clear() {
      if (scormStore && scormStore.active()) scormStore.clear();
    }
  }
};
