const pkg = require("./package.json");
const ImageminPlugin = require("imagemin-webpack-plugin").default;
const XMLPlugin = require("xml-webpack-plugin");
const scorm = process.env.VUE_APP_SCORM && process.env.VUE_APP_SCORM.trim();
const PID = pkg.name;
const TITLE = pkg.title;
const plugins = [];

console.log(`TITLE “${TITLE}” (${PID})`);

if (process.env.NODE_ENV === "production")
  plugins.push(
    new ImageminPlugin({
      svgo: {
        plugins: [{ convertTransform: false }, { collapseGroups: false }]
      }
    })
  );
if (["scorm12", "scorm2004"].includes(scorm))
  plugins.push(
    new XMLPlugin({
      files: [
        {
          template: `src/${scorm}/imsmanifest.ejs`,
          filename: "imsmanifest.xml",
          data: { PID, TITLE }
        }
      ]
    })
  );

module.exports = {
  publicPath: "./",
  productionSourceMap: false,
  filenameHashing: false,
  configureWebpack: { plugins },
  chainWebpack: config => {
    config.resolve.symlinks(false);
    config.plugins.delete("preload");
    config.module.rule("media").test(/\.(vtt|mp4|webm|ogg|mp3|wav|flac|aac)(\?.*)?$/);
    config.module
      .rule("schema")
      .test(/\.(xsd|dtd)$/)
      .use("file-loader")
      .loader("file-loader")
      .options({
        name: "[name].[ext]"
      });
  },

  css: {
    sourceMap: true,
    loaderOptions: {}
  },

  lintOnSave: true
};
